@@ -224,7 +224,12 @@ vfolder_export (nodePtr node,
 void
 vfolder_reset (vfolderPtr vfolder)
 {
-	itemlist_unload (FALSE);
+	itemlist_unload ();
+
+	if (vfolder->loader) {
+		g_object_unref (vfolder->loader);
+		vfolder->loader = NULL;
+	}
 
 	g_list_free (vfolder->itemset->ids);
 	vfolder->itemset->ids = NULL;
@@ -237,7 +242,8 @@ vfolder_rebuild (nodePtr node)
 	vfolderPtr	vfolder = (vfolderPtr)node->data;
 
 	vfolder_reset (vfolder);
-	itemlist_add_search_result (vfolder_loader_new (node));
+	vfolder->loader = vfolder_loader_new (node);
+	itemlist_add_search_result (vfolder->loader);
 }
 
 static void
@@ -247,6 +253,11 @@ vfolder_free (nodePtr node)
 
 	debug_enter ("vfolder_free");
 
+	if (vfolder->loader) {
+		g_object_unref (vfolder->loader);
+		vfolder->loader = NULL;
+	}
+
 	vfolders = g_slist_remove (vfolders, vfolder);
 	itemset_free (vfolder->itemset);
 
